

OpticalElement
===============================

.. currentmodule:: poppy.poppy_core

.. autoclass:: OpticalElement
   :show-inheritance:

   
     
   

   
   

   .. rubric:: Attributes Summary

   .. autosummary::
   
      ~OpticalElement.shape

   
   

   
   

   .. rubric:: Methods Summary

   .. autosummary::
   
      ~OpticalElement.display
      ~OpticalElement.getPhasor

   
   

   
   

   .. rubric:: Attributes Documentation

   
   .. autoattribute:: shape

   
   

   
   

   .. rubric:: Methods Documentation

   
   .. automethod:: display
   .. automethod:: getPhasor

   
   